pub fn take_last_resource_fatal() -> Option<Error>
Take (and clear) the latched resource fatal, if any. Returns the structured Error so a boundary that received only a flattened string can propagate the real thing.
Error